@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.29';
+our $VERSION = '0.2.30';
 
 1;
 
@@ -40,15 +40,7 @@ sub execute_cmd2 {
 
     my $stdout; my $stderr; my $exit;
 
-    if (get_prop('verbose')){
-      ($stdout, $stderr, $exit) =  Capture::Tiny::tee {
-        system( $cmd );
-      }
-    }else{
-      ($stdout, $stderr, $exit) =  Capture::Tiny::capture {
-        system( $cmd );
-      }
-    }
+    ( $stdout, $stderr, $exit) =  Capture::Tiny::tee { system( $cmd ) };
 
     return ($exit >> 8,$stdout.$stderr);
 }
@@ -168,20 +160,21 @@ sub run_story_file {
 
     my $task_name = get_prop('task_name');
 
-    note(
-      "\n". 
-      ( nocolor() ? short_story_name($task_name) : colored(['yellow'],short_story_name($task_name)) ).
-      ' at '.timestamp()
-    );
+    my $format = get_prop('format');
+
+    unless ( $format eq 'concise'){
+      note(
+        
+        chr(8226).($task_name ? $task_name.' at ' : ' at ').timestamp()."\n".( nocolor() ? short_story_name($task_name) : colored(['yellow'],short_story_name($task_name)) )
+      );
+    }
 
     if ( get_stdout() ){
 
         note("stdout is already set") if debug_mod12;
-        if ( get_prop('verbose') ){
-          for my $l (split /\n/, get_stdout()){
-            note( nocolor() ? $l : colored(['white'],$l));
-          };
-        }
+        for my $l (split /\n/, get_stdout()){
+          note($l);
+        };
         set_prop( stdout => get_stdout() );
         set_prop( scenario_status => 1 );
 
@@ -286,7 +279,7 @@ sub generate_asserts {
 
     eval { dsl()->{output} = run_story_file() };
 
-
+  
     if ($@) {
       $STATUS = 0;
       die "story run error: $@";
@@ -330,17 +323,18 @@ sub outh_ok {
     my $message   = shift;
     my $exit_code = shift;
 
-    if ($status) {
-      print nocolor() ? "ok\t$message\n" : colored(['green'],"ok\t$message")."\n";
-    } else {
-      print nocolor() ? "not ok\t$message\n" : colored(['red'], "not ok\t$message")."\n";
-    };
+    my $format = get_prop('format');
+
+    if ($format ne 'concise'){
+      if ($status) {
+        print nocolor() ? "ok\t$message\n" : colored(['green'],"ok\t$message")."\n";
+      } else {
+        print nocolor() ? "not ok\t$message\n" : colored(['red'], "not ok\t$message")."\n";
+      }
+    }
 
-      
     if ($status == 0 and $STATUS != 0 ){
-      #print "STATUS: $STATUS ... \n";
       $STATUS = ($exit_code == 1 ) ? -1 : 0;
-      #print "STATUS: $STATUS ... \n";
     }
 }
 
@@ -348,10 +342,12 @@ sub note {
 
     my $message = shift;
 
+    binmode(STDOUT, ":utf8");
     print "$message\n";
 
 }
 
+
 sub print_meta {
 
     open META, get_prop('story_dir')."/meta.txt" or die $!;
@@ -371,7 +367,8 @@ sub print_meta {
 
 sub short_story_name {
 
-    my $task_name = shift||"[s]";
+    my $task_name = shift;
+
     my $story_dir = get_prop('story_dir');
 
     my $cwd_size = scalar(split /\//, get_prop('project_root_dir'));
@@ -387,10 +384,13 @@ sub short_story_name {
 
     my $story_vars = story_vars_pretty();
 
+    my @ret;
+
+    push @ret, "[path] $short_story_dir" if $short_story_dir;
+    push @ret, "[params] $story_vars" if $story_vars;
+
+    join "\n", @ret;
 
-    return $task_name ? 
-      ( $task_name.($short_story_dir ? ' '.$short_story_dir : '').( $story_vars  ? " params: $story_vars" : "" )) :
-      $short_story_dir.( $story_vars  ? " params: $story_vars" : "" );
 }
 
 sub timestamp {
@@ -1520,12 +1520,15 @@ Enable/disable debug mode:
 
 =item *
 
-C<--silent> 
+C<--format> 
 
 
 =back
 
-Run in silent mode. By default strun prints all scenarios output, to disable this choose C<--silent> option.
+Sets report format. Available formats: C<concise|default>. Default value is C<default>.
+
+In concise format strun shrink output to only STDOUT/STDERR comes from story scenarios.
+It's useful when you want to parse "raw" script output by external commands.
 
 =over
 
